@@ -1,5 +1,4 @@
 import json
-import os
 from pathlib import Path
 from typing import Optional
 
@@ -14,5 +13,5 @@ def parse_file(path: Path) -> Optional[dt.AnnotationFile]:
         data = json.load(f)
         annotations = list(filter(None, map(parse_darwin_annotation, data["annotations"])))
         annotation_classes = set([annotation.annotation_class for annotation in annotations])
-        filename = data['image']['original_filename']
+        filename = data["image"]["original_filename"]
         return dt.AnnotationFile(path, filename, annotation_classes, annotations)
