@@ -14,10 +14,4 @@ except ImportError:
         f"darwin.torch requires pycocotools. Install it using: pip install cython; pip install -U 'git+https://github.com/cocodataset/cocoapi.git#subdirectory=PythonAPI'"
     ) from None
 
-from .dataset import (
-    ClassificationDataset,
-    DarwinDataset,
-    InstanceSegmentationDataset,
-    SemanticSegmentationDataset,
-    get_dataset,
-)
+from .dataset import get_dataset  # noqa
